Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(319)

Unified Diff: media/audio/audio_output_resampler.h

Issue 11410012: Collapse AudioRendererMixer and OnMoreDataResampler into AudioTransform. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: First draft. Created 8 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | media/audio/audio_output_resampler.cc » ('j') | media/audio/audio_output_resampler.cc » ('J')
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: media/audio/audio_output_resampler.h
diff --git a/media/audio/audio_output_resampler.h b/media/audio/audio_output_resampler.h
index 764343777b3bcf888fd1700b6b72c47361dd464b..5e9c635f28638afcbb95a6efb856429358aaa217 100644
--- a/media/audio/audio_output_resampler.h
+++ b/media/audio/audio_output_resampler.h
@@ -17,7 +17,7 @@
namespace media {
-class OnMoreDataResampler;
+class OnMoreDataTransform;
Chris Rogers 2012/11/14 23:50:49 OnMoreDataTransform sounds a bit awkward, how abou
DaleCurtis 2012/11/16 23:51:05 Done.
// AudioOutputResampler is a browser-side resampling and rebuffering solution
// which ensures audio data is always output at given parameters. The rough
@@ -39,9 +39,6 @@ class OnMoreDataResampler;
// high latency path once we have channel mixing and support querying for the
// hardware's configured bit depth. Monitor the UMA stats for fallback and
// remove fallback support once it's stable. http://crbug.com/148418
-//
-// Currently channel downmixing and upmixing is not supported.
-// TODO(dalecurtis): Add channel remixing. http://crbug.com/138762
class MEDIA_EXPORT AudioOutputResampler : public AudioOutputDispatcher {
public:
AudioOutputResampler(AudioManager* audio_manager,
@@ -63,21 +60,17 @@ class MEDIA_EXPORT AudioOutputResampler : public AudioOutputDispatcher {
friend class base::RefCountedThreadSafe<AudioOutputResampler>;
virtual ~AudioOutputResampler();
- // Used to initialize the FIFO and resamplers.
+ // Used to initialize and reinitialize |dispatcher_|.
void Initialize();
// Dispatcher to proxy all AudioOutputDispatcher calls too.
scoped_refptr<AudioOutputDispatcher> dispatcher_;
// Map of outstanding OnMoreDataResampler objects. A new object is created
// on every StartStream() call and destroyed on CloseStream().
- typedef std::map<AudioOutputProxy*, OnMoreDataResampler*> CallbackMap;
+ typedef std::map<AudioOutputProxy*, OnMoreDataTransform*> CallbackMap;
CallbackMap callbacks_;
- // Ratio of input bytes to output bytes used to correct playback delay with
- // regard to buffering and resampling.
- double io_ratio_;
-
// Used by AudioOutputDispatcherImpl; kept so we can reinitialize on the fly.
base::TimeDelta close_delay_;
« no previous file with comments | « no previous file | media/audio/audio_output_resampler.cc » ('j') | media/audio/audio_output_resampler.cc » ('J')
@@ -63,21 +60,17 @@ class MEDIA_EXPORT AudioOutputResampler : public AudioOutputDispatcher {
// Dispatcher to proxy all AudioOutputDispatcher calls too.
scoped_refptr<AudioOutputDispatcher> dispatcher_;
- // Map of outstanding OnMoreDataResampler objects. A new object is created
+ // Map of outstanding OnMoreDataTransform objects. A new object is created
// on every StartStream() call and destroyed on CloseStream().

Powered by Google App Engine
This is Rietveld 408576698